==> structure-server-0.0.3.tgz: package/test/unit/server.js <==
import Server from '../../index'

/** @test {Server} */
describe('HTTP Server', function() {

  it('should initialize', function(done) {

    var api = new Server({
      sockets: false
    })

    expect(api).to.be.an('object')
    expect(api.debugRoutes).to.be.a('function')
    expect(api.logRequestInfo).to.be.a('function')
    expect(api.server).to.be.an('function') // Express server
    expect(api.router).to.be.an('object')
    expect(api.start).to.be.a('function')
    expect(api.stop).to.be.a('function')
    expect(api.use).to.be.a('function')

    done()

  })

  /** @test {Server#start} */
  it('should start', function(done) {

    var api = new Server({
      sockets: false
    })
    sinon.stub(api.server, 'listen').returns(api.server)

    api.start()

    expect(api.server.listen.calledOnce).to.be.true

    done()

  })

  /** @test {Server#stop} */
  it('should stop', function(done) {

    var api = new Server({
      sockets: false
    })
    sinon.stub(api.server, 'listen').returns(api.server)
    sinon.stub(api, 'stop')

    api.start()
    api.stop()

    expect(api.stop.calledOnce).to.be.true

    done()

  })

  it.skip('should prevent query parameter pollution', async function(done) {

    var pkg = {
      title: 'My Template'
    }

    var res = await new MockHTTPServer()
      .post(`/api/v${process.env.API_VERSION}/templates?desc=cool&desc=cooler`)
      .send(pkg)

    expect(res.body.req.queryPolluted).to.be.true
    expect(res.body.req.query.desc).to.equal('cooler')

    done()

  })

})

==> structure-server-0.0.5.tgz: package/test/unit/server.js <==
import express from 'express'
import Router from 'structure-router'
import Server from '../../index'

/** @test {Server} */
describe('HTTP Server', function() {

  it('should initialize', function() {

    var api = new Server({
      sockets: false
    })

    expect(api).to.be.an('object')
    expect(api.debugRoutes).to.be.a('function')
    expect(api.logRequestInfo).to.be.a('function')
    expect(api.server).to.be.an('function') // Express server
    expect(api.router).to.be.an('object')
    expect(api.start).to.be.a('function')
    expect(api.stop).to.be.a('function')
    expect(api.use).to.be.a('function')

  })

  /** @test {Server#start} */
  it('should start', function() {

    var api = new Server({
      sockets: false
    })
    sinon.stub(api.server, 'listen').returns(api.server)

    api.start()

    expect(api.server.listen.calledOnce).to.be.true

  })

  /** @test {Server#stop} */
  it('should stop', function() {

    var api = new Server({
      sockets: false
    })
    sinon.stub(api.server, 'listen').returns(api.server)
    sinon.stub(api, 'stop')

    api.start()
    api.stop()

    expect(api.stop.calledOnce).to.be.true

  })

  it.skip('should prevent query parameter pollution', async function() {

    var pkg = {
      title: 'My Template'
    }

    var res = await new MockHTTPServer()
      .post(`/api/v${process.env.API_VERSION}/templates?desc=cool&desc=cooler`)
      .send(pkg)

    expect(res.body.req.queryPolluted).to.be.true
    expect(res.body.req.query.desc).to.equal('cooler')

  })

  it.skip('should generate routes list', function(done) {

    const router = express.Router()

    router.get('/:id', function() {})
    router.get('/', function() {})

    const api = new Server({
      router: new Router({
        routes: [
          {
            routeName: 'foo',
            routes: router
          }
        ]
      })
    })

    api.start()

  })

})
